@@ -2,17 +2,31 @@ package LaTeX::Pod;
 
 use strict;
 use warnings;
+use boolean qw(true false);
 
 use Carp qw(croak);
-use LaTeX::TOM;
+use LaTeX::TOM ();
+use Params::Validate ':all';
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
+
+validation_options(
+    on_fail => sub
+{
+    my ($error) = @_;
+    chomp $error;
+    croak $error;
+},
+    stack_skip => 2,
+);
 
 sub new
 {
     my $class = shift;
 
     my $self = bless {}, ref($class) || $class;
+
+    $self->_init_check(@_);
     $self->_init(@_);
 
     return $self;
@@ -59,13 +73,31 @@ sub convert
     return $self->_pod_finalize;
 }
 
+sub _init_check
+{
+    my $self = shift;
+
+    validate_pos(@_, { type => SCALAR });
+
+    my ($file) = @_;
+    my $error = sub
+    {
+        return 'does not exist' unless -e shift;
+        return 'is not a file'  unless -f _;
+        return 'is empty'       unless -s _;
+        return                            undef;
+
+    }->($file);
+
+    defined $error and croak "Cannot open `$file': $error";
+}
+
 sub _init
 {
-    my ($self, $file) = @_;
+    my $self = shift;
+    my ($file) = @_;
 
-    croak "$file: $!" unless -f $file;
-
-    $self->{file}      = $file;
+    $self->{file} = $file;
     $self->{title_inc} = 1;
 
     @{$self->{dispatch_text}} = (
@@ -94,7 +126,7 @@ sub _init_tom
 {
     my $self = shift;
 
-    # silently discard warnings about unparseable latex
+    # silently discard warnings about unparseable LaTeX
     my $parser   = LaTeX::TOM->new(2);
     my $document = $parser->parseFile($self->{file});
     my $nodes    = $document->getAllNodes;
@@ -110,7 +142,7 @@ sub _process_directives
         if ($self->_is_set_node($node)) {
             $self->_unregister_node($node);
 
-            return 1;
+            return true;
         }
     }
 
@@ -120,10 +152,10 @@ sub _process_directives
         $self->_pod_add('=head1 '.$self->{current_node}->getNodeText);
         $self->{title_inc}++;
 
-        return 1;
+        return true;
     }
 
-    return 0;
+    return false;
 }
 
 sub _process_text_title
@@ -276,7 +308,8 @@ sub _process_subsection
 
 sub _process_spec_chars
 {
-    my ($self, $text) = @_;
+    my $self = shift;
+    my ($text) = @_;
 
     my %umlauts = (a => '',
                    A => '',
@@ -298,7 +331,8 @@ sub _process_spec_chars
 
 sub _process_tags
 {
-    my ($self, $tag) = @_;
+    my $self = shift;
+    my ($tag) = @_;
 
     my $text = $self->{current_node}->getNodeText;
 
@@ -306,7 +340,7 @@ sub _process_tags
                 textsf => 'C',
                 emph   => 'I');
 
-    $self->{append_following} = 1;
+    $self->{append_following} = true;
 
     $self->_pod_append("$tags{$tag}<$text>");
     $self->_unregister_node($tag);
@@ -314,27 +348,30 @@ sub _process_tags
 
 sub _pod_add
 {
-    my ($self, $content) = @_;
+    my $self = shift;
+    my ($content) = @_;
 
     if (!$self->{append_following}) {
         push @{$self->{pod}}, $content;
     }
     else {
         $self->_pod_append($content);
-        $self->{append_following} = 0;
+        $self->{append_following} = false;
     }
 }
 
 sub _pod_append
 {
-    my ($self, $content) = @_;
+    my $self = shift;
+    my ($content) = @_;
 
     $self->{pod}->[-1] .= $content;
 }
 
 sub _pod_scrub_newlines
 {
-    my ($self, $text) = @_;
+    my $self = shift;
+    my ($text) = @_;
 
     $$text =~ s/^\n*//;
     $$text =~ s/\n*$//;
@@ -342,7 +379,8 @@ sub _pod_scrub_newlines
 
 sub _pod_scrub_whitespaces
 {
-    my ($self, $text) = @_;
+    my $self = shift;
+    my ($text) = @_;
 
     $$text =~ s/^\s*//;
     $$text =~ s/\s*$//;
@@ -366,52 +404,58 @@ sub _pod_finalize
 
 sub _register_node
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
-    $self->{node}{$item} = 1;
+    $self->{node}{$item} = true;
 }
 
 sub _is_set_node
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
-    return $self->{node}{$item} ? 1 : 0;
+    return $self->{node}{$item} ? true : false;
 }
 
 sub _unregister_node
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
     delete $self->{node}{$item};
 }
 
 sub _register_previous
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
-    $self->{previous}{$item} = 1;
+    $self->{previous}{$item} = true;
 }
 
 sub _is_set_previous
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
-    my @items = ref($item) eq 'ARRAY' ? @$item : ($item);
+    my @items = ref $item eq 'ARRAY' ? @$item : ($item);
 
     foreach my $item_single (@items) {
         if ($self->{previous}{$item_single}) {
-            return 1;
+            return true;
         }
     }
 
-    return 0;
+    return false;
 }
 
 sub _unregister_previous
 {
-    my ($self, $item) = @_;
+    my $self = shift;
+    my ($item) = @_;
 
-    my @items = ref($item) eq 'ARRAY' ? @$item : ($item);
+    my @items = ref $item eq 'ARRAY' ? @$item : ($item);
 
     foreach my $item_single (@items) {
         if ($self->{previous}{$item_single}) {
@@ -428,22 +472,22 @@ LaTeX::Pod - Transform LaTeX source files to POD (Plain old documentation)
 
  use LaTeX::Pod;
 
- my $parser = LaTeX::Pod->new('/path/to/latex-source');
+ $parser = LaTeX::Pod->new('/path/to/source');
  print $parser->convert;
 
 =head1 DESCRIPTION
 
 C<LaTeX::Pod> converts LaTeX sources to Perl's POD (Plain old documentation)
-format. Currently only a subset of the available LaTeX language is suppported -
-see below for detailed information.
+format. Currently only a subset of the available LaTeX language is supported;
+see below for further information.
 
 =head1 CONSTRUCTOR
 
 =head2 new
 
-The constructor requires that the path to the latex source must be declared:
+The constructor requires that the path to the LaTeX source must be defined:
 
- $parser = LaTeX::Pod->new('/path/to/latex-source');
+ $parser = LaTeX::Pod->new('/path/to/source');
 
 Returns the parser object.
 
@@ -451,15 +495,15 @@ Returns the parser object.
 
 =head2 convert
 
-There is only one public method available, C<convert>:
+There is only one public method available, namely C<convert()>:
 
  $parser->convert;
 
-Returns the POD document as string.
+Returns the computed POD document as string.
 
 =head1 SUPPORTED LANGUAGE SUBSET
 
-It's not much, but there's more to come:
+Currently supported:
 
 =over 4
 
@@ -483,9 +527,11 @@ It's not much, but there's more to come:
 
 The current implementation is a bit I<flaky> because C<LaTeX::TOM>, the framework
 being used for parsing the LaTeX nodes, makes a clear distinction between various
-types of nodes. As example, an \item directive has quite often a separate text which
-is associated with former one. And they can't be detected without some kind of
-sophisticated "look-behind", which is what is being done.
+types of nodes. As example, an \item directive has quite often a separate text
+associated with it as its content. Such directives and their expected converted
+relatives within the output stream possibly cannot be easily detected without
+some kind of sophisticated "look-behind" mechanism, which is how C<LaTeX::Pod>
+internally functions.
 
 C<LaTeX::Pod> was designed with the intention to be I<context-sensitive> aware.
 This is being achieved by setting which node has been seen before the current one in
